<template>
    <div class="dialog-table-container">
        <el-table :element-loading-background="loadingColor" v-loading="loading" height="65vh" align="center"
            :data="tableData" class="dialog_table" :cell-style="{ 'text-align': 'center' }"
            :header-cell-style="{ 'text-align': 'center' }" @expand-change="expandChange" row-key="id">
            <el-table-column type="expand" label="点击查看详情" width="140">
                <template slot-scope="props">
                    <el-form label-position="top" class="dialog-table-expand">
                        <el-row>
                            <el-form-item label="解决问题：">
                                <span>{{ props.row.solveProblem }}</span>
                            </el-form-item>
                        </el-row>
                        <el-row>
                            <el-form-item label="取得成果">
                                <span>{{ props.row.result }}</span>
                            </el-form-item>
                        </el-row>
                        <el-row>
                            <el-form-item label="佐证材料：">
                                <el-row v-if="props.row.files">
                                    <el-col :span="8" v-for="(file, index) in props.row.files" :key="index">
                                        <div class="file-style">
                                            <div class="file-item">
                                                <span class="file-name" :title="file.name
                                                        ? file.name
                                                        : file.fileName +
                                                        '.' +
                                                        file.extensionName
                                                    ">{{
        file.name
        ? file.name
        : file.fileName +
        '.' +
        file.extensionName
    }}</span>
                                                <span class="file-btn short">
                                                    <el-link type="primary" :underline="false" @click="
                                                        handlePreview(file)
                                                        " style="color: #fff">预览</el-link>
                                                    <el-link type="primary" :underline="false" style="color: #fff" @click="
                                                        handleDownloadFile(
                                                            file
                                                        )
                                                        ">下载</el-link>
                                                </span>
                                            </div>
                                        </div>
                                    </el-col>
                                </el-row>
                            </el-form-item>
                        </el-row>
                    </el-form>
                </template>
            </el-table-column>
            <el-table-column prop="effectTopic" label="获推广经验名称" />
            <el-table-column prop="createOrgName" label="首创地" width="100"></el-table-column>
            <el-table-column prop="specificDetails" label="获推广形式" width="300">
                <template slot-scope="props">
                    {{
                        getSubDictName(
                            'cxxs',
                            'cxxs-jtqx',
                            props.row.effectForm,
                            props.row.specificDetails
                        )
                    }}
                </template>
            </el-table-column>
        </el-table>
        <filePreview ref="filePreview" :appendToBody="true"></filePreview>
        <pagenation :pageResult="prarms.pageBean" @currentChange="pageChange" class="pagenation"></pagenation>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/districView.js'
import filePreview from '@/components/FilePreview/filePreview.vue'
import utils from '@/utils.js'
import pagenation from './pagenation.vue'
const portal = window.context.portal
export default {
    components: {
        filePreview,
        pagenation,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            prarms: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'EFFECT_FORM_',
                        relation: 'AND',
                        value: 2,
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'ee.COMPLETION_YEAR_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LESS_EQUAL',
                        parentGroup: '',
                        property: 'ee.COMPLETION_QUARTER_', // 字段名
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
            paramsFile: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'BIZ_ID_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        this.loadData()
    },
    methods: {
        pageChange(key) {
            this.prarms.pageBean.page = key
            this.loadData()
        },
        getSubDictName(code, subCode, value, subValue) {
            let dict = utils.getDictItemsFromCache(code)
            let name = ''
            dict.forEach((item) => {
                if (item.value == value) {
                    item.lowerDic[subCode].forEach((sub) => {
                        if (sub.value == subValue) {
                            name = sub.name
                        }
                    })
                }
            })
            return name
        },
        expandChange(row, expandedRows) {
            console.log(row, expandedRows)
            if (row.files) return
            this.getFiles(row)
        },
        getFiles(row) {
            let files = []
            this.paramsFile.querys[0].value = row.id
            apiList.getFiles(this.paramsFile, (data) => {
                row.files = data.rows
            })
            let index = this.tableData.findIndex((item) => item.id == row.id)
            this.tableData.splice(index, 1, row)
        },
        handlePreview(file) {
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            let type = file.fileType || (file.extensionName
                ? file.extensionName
                : file.name.split('.')[1])
            this.$refs.filePreview.previewUrl = this.previewUrl + id
            this.$refs.filePreview.open(type)
        },
        // 文件下载
        handleDownloadFile(file) {
            console.log(file)
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
        },
        loadData() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            this.prarms.querys[1].value = searchDate.year
            this.prarms.querys[2].value = searchDate.quarter
            apiList.getBookAccount(this.prarms, (res) => {
                console.log(res)
                if (res && res.rows) {
                    this.tableData = res.rows
                    this.prarms.pageBean.page = res.page
                    this.prarms.pageBean.pageSize = res.pageSize
                    this.prarms.pageBean.total = res.total
                }
                this.loading = false
            })
        },
    },
}
</script>
<style lang="scss" scoped>
.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 2px 10px;
    padding-right: 5px;
    border-radius: 2px;

    a {
        margin-right: 8px;
        user-select: none;
    }

    .file-name {
        width: calc(100% - 80px);
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
    }

    .file-btn {
        display: inline-block;
        width: 140px;
    }

    .file-btn.short {
        width: 90px;
    }
}

.file-item:hover {
    background-color: rgba(1, 33, 90, 0.6);
}
</style>
<style lang="scss">
@import './table.scss';
</style>
